@@ -2,6 +2,7 @@
 import aiohttp as aiohttp
 
 from itle.base import RestApi
+from itle.ddk.ddk_channel_type import DDKChannelType3
 
 
 class DDKCmsPromUrlRequest(RestApi):
@@ -9,7 +10,7 @@ class DDKCmsPromUrlRequest(RestApi):
     def __init__(self, aio_http: aiohttp, domain: str, port: int):
         super(DDKCmsPromUrlRequest, self).__init__(aio_http, domain, port)
         self.ddk_pid_list = None  # 'pid0, pid1,'
-        self.channel_type = None
+        self.channel_type = DDKChannelType3.PC_SHOPPING.value
         self.keyword = None
         self.custom_params = None
         self.generate_mobile = None
